@@ -61,12 +61,13 @@ class Client(object):
         'version': '0.1'
     }
 
-    def __init__(self, personal_access_token, host="https://dev.tybaenergy.com"):
+    def __init__(self, personal_access_token, host="https://dev.tybaenergy.com", request_args=None):
         """A :class:`Client` object for interacting with Tyba's API.
         """
         self.personal_access_token = personal_access_token
         self.host = host
         self.services = Services(self)
+        self.request_args = {} if request_args is None else request_args
 
     def _auth_header(self):
         return self.personal_access_token
@@ -77,12 +78,15 @@ class Client(object):
     def get(self, route, params=None):
         return requests.get(self._base_url() + route,
                             params=params,
-                            headers={"Authorization": self._auth_header()})
+                            headers={"Authorization": self._auth_header()},
+                            **self.request_args)
 
     def post(self, route, json):
         return requests.post(self._base_url() + route,
                              json=json,
-                             headers={"Authorization": self._auth_header()})
+                             headers={"Authorization": self._auth_header()},
+                             **self.request_args
+                             )
 
     def schedule_pv(self, pv_model: PVModel):
         model_json_dict = pv_model.to_dict()
