@@ -269,20 +269,20 @@ class StorageInputs(object):
     annual_cycle_limit: t.Optional[float] = opt_field()
     window: t.Optional[int] = opt_field()
     step: t.Optional[int] = opt_field()
+    flexible_solar: t.Optional[bool] = opt_field()
 
-dam_energy_prices = t.List[float]
 
 @dataclass_json
 @dataclass
 class AncillaryEnergyPrices(object):
-    dam: dam_energy_prices
+    dam: t.List[float]
     rtm: t.List[float]
 
 @dataclass_json
 @dataclass
 class StorageModel(object):
     storage_inputs: StorageInputs
-    energy_prices: t.Union[AncillaryEnergyPrices,dam_energy_prices]
+    energy_prices: t.Union[AncillaryEnergyPrices, t.List[float]]
 
 @dataclass_json
 @dataclass
@@ -301,13 +301,15 @@ class ReserveMarket(object):
 @dataclass_json
 @dataclass
 class AncillaryUpMarkets(object):
-    rrs: t.Optional[ReserveMarket] = opt_field()
+    reserves: t.Optional[ReserveMarket] = opt_field()
     reg_up: t.Optional[ReserveMarket] = opt_field()
+    generic_up: t.Optional[ReserveMarket] = opt_field()
 
 @dataclass_json
 @dataclass
 class AncillaryDownMarket(object):
-    reg_down: ReserveMarket
+    reg_down: t.Optional[ReserveMarket] = opt_field()
+    generic_down: t.Optional[ReserveMarket] = opt_field()
 
 @dataclass_json
 @dataclass
@@ -334,7 +336,7 @@ class PVStorageModel(object):
     storage_coupling: StorageCoupling = field(metadata=StorageCoupling.__metadata__)
     pv_inputs: PVModel
     storage_inputs: StorageInputs
-    energy_prices: t.Union[AncillaryEnergyPrices, dam_energy_prices]
+    energy_prices: t.Union[AncillaryEnergyPrices, t.List[float]]
     enable_grid_charge_year: t.Optional[int] = opt_field()
     ancillary_markets: t.Optional[AncillaryMarkets] = opt_field()
 
